compute_conditional_sd: Computes posterior draws of structural shock conditional...

View source: R/compute_conditional_sd.R

compute_conditional_sdR Documentation

Computes posterior draws of structural shock conditional standard deviations

Description

Each of the draws from the posterior estimation of models is transformed into a draw from the posterior distribution of the structural shock conditional standard deviations.

Usage

compute_conditional_sd(posterior)

Arguments

posterior

posterior estimation outcome obtained by running the estimate function. The interpretation depends on the normalisation of the shocks using function normalise(). Verify if the default settings are appropriate.

Value

An object of class PosteriorSigma, that is, an NxTxS array with attribute PosteriorSigma containing S draws of the structural shock conditional standard deviations.

Author(s)

Tomasz Woźniak wozniak.tom@pm.me

See Also

estimate, normalise, summary

Examples

specification  = specify_bsvar$new(us_fiscal_lsuw)
burn_in        = estimate(specification, 5)
posterior      = estimate(burn_in, 5)
sigma          = compute_conditional_sd(posterior)

# workflow with the pipe |>
############################################################
us_fiscal_lsuw |>
  specify_bsvar$new() |>
  estimate(S = 5) |> 
  estimate(S = 5) |> 
  compute_conditional_sd() -> csd


bsvars documentation built on Aug. 22, 2026, 5:09 p.m.