compute_conditional_sd.PosteriorBSVARMIX: Computes posterior draws of structural shock conditional...

View source: R/compute_conditional_sd.R

compute_conditional_sd.PosteriorBSVARMIXR Documentation

Computes posterior draws of structural shock conditional standard deviations

Description

Each of the draws from the posterior estimation of models is transformed into a draw from the posterior distribution of the structural shock conditional standard deviations.

Usage

## S3 method for class 'PosteriorBSVARMIX'
compute_conditional_sd(posterior)

Arguments

posterior

posterior estimation outcome - an object of class PosteriorBSVARMIX obtained by running the estimate function.

Value

An object of class PosteriorSigma, that is, an NxTxS array with attribute PosteriorSigma containing S draws of the structural shock conditional standard deviations.

Author(s)

Tomasz Woźniak wozniak.tom@pm.me

See Also

estimate, normalise, summary

Examples

specification  = specify_bsvar_mix$new(us_fiscal_lsuw, M = 2)
burn_in        = estimate(specification, 5)
posterior      = estimate(burn_in, 5)
csd     = compute_conditional_sd(posterior)

# workflow with the pipe |>
############################################################
us_fiscal_lsuw |>
  specify_bsvar_mix$new(M = 2) |>
  estimate(S = 5) |> 
  estimate(S = 5) |> 
  compute_conditional_sd() -> csd
  

bsvars documentation built on Aug. 22, 2026, 5:09 p.m.