View source: R/compute_fitted_values.R
| compute_fitted_values.PosteriorBSVARMSH | R Documentation |
Each of the draws from the posterior estimation of models from packages bsvars or bsvarSIGNs is transformed into a draw from the data predictive density.
## S3 method for class 'PosteriorBSVARMSH'
compute_fitted_values(posterior)
posterior |
posterior estimation outcome - an object of class
|
An object of class PosteriorFitted, that is, an NxTxS
array with attribute PosteriorFitted containing S draws from
the data predictive density.
Tomasz Woźniak wozniak.tom@pm.me
estimate, summary
specification = specify_bsvar_msh$new(us_fiscal_lsuw, M = 2)
burn_in = estimate(specification, 5)
posterior = estimate(burn_in, 5)
# compute draws from in-sample predictive density
csd = compute_fitted_values(posterior)
# workflow with the pipe |>
############################################################
us_fiscal_lsuw |>
specify_bsvar_msh$new(M = 2) |>
estimate(S = 5) |>
estimate(S = 5) |>
compute_fitted_values() -> csd
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.