compute_historical_decompositions: Computes posterior draws of historical decompositions

View source: R/compute_historical_decompositions.R

compute_historical_decompositionsR Documentation

Computes posterior draws of historical decompositions

Description

Each of the draws from the posterior estimation of models from packages bsvars or bsvarSIGNs is transformed into a draw from the posterior distribution of the historical decompositions. IMPORTANT! The historical decompositions are interpreted correctly for covariance stationary data. Application to unit-root non-stationary data might result in non-interpretable outcomes.

Usage

compute_historical_decompositions(posterior, show_progress = TRUE)

Arguments

posterior

posterior estimation outcome obtained by running the estimate function. The interpretation depends on the normalisation of the shocks using function normalise(). Verify if the default settings are appropriate.

show_progress

a logical value, if TRUE the estimation progress bar is visible

Value

An object of class PosteriorHD, that is, an NxNxTxS array with attribute PosteriorHD containing S draws of the historical decompositions.

Author(s)

Tomasz Woźniak wozniak.tom@pm.me and Xiaolei Wang adamwang15@gmail.com

References

Kilian, L., & Lütkepohl, H. (2017). Structural VAR Tools, Chapter 4, In: Structural vector autoregressive analysis. Cambridge University Press.

See Also

estimate, normalise, summary

Examples

specification  = specify_bsvar$new(diff(us_fiscal_lsuw))
burn_in        = estimate(specification, 5)
posterior      = estimate(burn_in, 5)

# compute historical decompositions
hd            = compute_historical_decompositions(posterior)

# workflow with the pipe |>
############################################################
diff(us_fiscal_lsuw) |>
  specify_bsvar$new() |>
  estimate(S = 5) |> 
  estimate(S = 5) |> 
  compute_historical_decompositions() -> hd


bsvars documentation built on Aug. 22, 2026, 5:09 p.m.