View source: R/compute_historical_decompositions.R
| compute_historical_decompositions.PosteriorBSVARMIX | R Documentation |
Each of the draws from the posterior estimation of models from packages bsvars or bsvarSIGNs is transformed into a draw from the posterior distribution of the historical decompositions. IMPORTANT! The historical decompositions are interpreted correctly for covariance stationary data. Application to unit-root non-stationary data might result in non-interpretable outcomes.
## S3 method for class 'PosteriorBSVARMIX'
compute_historical_decompositions(posterior, show_progress = TRUE)
posterior |
posterior estimation outcome - an object of class
|
show_progress |
a logical value, if |
An object of class PosteriorHD, that is, an NxNxTxS array
with attribute PosteriorHD containing S draws of the historical
decompositions.
Tomasz Woźniak wozniak.tom@pm.me
Kilian, L., & Lütkepohl, H. (2017). Structural VAR Tools, Chapter 4, In: Structural vector autoregressive analysis. Cambridge University Press.
estimate, normalise, summary
specification = specify_bsvar_mix$new(us_fiscal_lsuw, M = 2)
burn_in = estimate(specification, 5)
posterior = estimate(burn_in, 5)
# compute historical decompositions
hd = compute_historical_decompositions(posterior)
# workflow with the pipe |>
############################################################
us_fiscal_lsuw |>
specify_bsvar_mix$new(M = 2) |>
estimate(S = 5) |>
estimate(S = 5) |>
compute_historical_decompositions() -> hds
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.