View source: R/compute_structural_shocks.R
| compute_structural_shocks.PosteriorBSVARMIX | R Documentation |
Each of the draws from the posterior estimation of models from packages bsvars or bsvarSIGNs is transformed into a draw from the posterior distribution of the structural shocks.
## S3 method for class 'PosteriorBSVARMIX'
compute_structural_shocks(posterior)
posterior |
posterior estimation outcome - an object of class
|
An object of class PosteriorShocks, that is, an NxTxS array with attribute PosteriorShocks
containing S draws of the structural shocks.
Tomasz Woźniak wozniak.tom@pm.me
estimate, normalise, summary
specification = specify_bsvar_mix$new(us_fiscal_lsuw, p = 1, M = 2)
burn_in = estimate(specification, 5)
posterior = estimate(burn_in, 5)
# compute structural shocks
shocks = compute_structural_shocks(posterior)
# workflow with the pipe |>
############################################################
us_fiscal_lsuw |>
specify_bsvar_mix$new(p = 1, M = 2) |>
estimate(S = 5) |>
estimate(S = 5) |>
compute_structural_shocks() -> ss
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.