compute_variance_decompositions: Computes posterior draws of the forecast error variance...

View source: R/compute_variance_decompositions.R

compute_variance_decompositionsR Documentation

Computes posterior draws of the forecast error variance decomposition

Description

Each of the draws from the posterior estimation of models from packages bsvars or bsvarSIGNs is transformed into a draw from the posterior distribution of the forecast error variance decomposition.

Usage

compute_variance_decompositions(posterior, horizon)

Arguments

posterior

posterior estimation outcome obtained by running the estimate function. The interpretation depends on the normalisation of the shocks using function normalise(). Verify if the default settings are appropriate.

horizon

a positive integer number denoting the forecast horizon for the forecast error variance decomposition computations.

Value

An object of class PosteriorFEVD, that is, an NxNx(horizon+1)xS array with attribute PosteriorFEVD containing S draws of the forecast error variance decomposition.

Author(s)

Tomasz Woźniak wozniak.tom@pm.me

References

Kilian, L., & Lütkepohl, H. (2017). Structural VAR Tools, Chapter 4, In: Structural vector autoregressive analysis. Cambridge University Press.

See Also

compute_impulse_responses, estimate, normalise, summary

Examples

specification  = specify_bsvar$new(us_fiscal_lsuw, p = 1)
burn_in        = estimate(specification, 5)
posterior      = estimate(burn_in, 5)

# compute forecast error variance decomposition 2 years ahead
fevd           = compute_variance_decompositions(posterior, horizon = 8)

# workflow with the pipe |>
############################################################
us_fiscal_lsuw |>
  specify_bsvar$new(p = 1) |>
  estimate(S = 5) |> 
  estimate(S = 5) |> 
  compute_variance_decompositions(horizon = 8) -> fevd


bsvars documentation built on Aug. 22, 2026, 5:09 p.m.