| forecast.PosteriorBSVAR | R Documentation |
Samples from the joint predictive density of all of the dependent
variables for models at forecast horizons from 1 to horizon specified as
an argument of the function.
## S3 method for class 'PosteriorBSVAR'
forecast(
object,
horizon = 1,
exogenous_forecast = NULL,
conditional_forecast = NULL,
...
)
object |
posterior estimation outcome - an object of class
|
horizon |
a positive integer, specifying the forecasting horizon. |
exogenous_forecast |
a matrix of dimension |
conditional_forecast |
a |
... |
not used |
A list of class Forecasts containing the
draws from the predictive density and for heteroskedastic models the draws
from the predictive density of structural shocks conditional standard
deviations and data. The output elements include:
an NxTxS array with the draws from predictive density
an NxT matrix with the data on dependent variables
an NxTxS array with the mean of the predictive density
an NxTxS array with the covariance of the predictive density
Tomasz Woźniak wozniak.tom@pm.me
specification = specify_bsvar$new(us_fiscal_lsuw)
burn_in = estimate(specification, 5)
posterior = estimate(burn_in, 5)
predictive = forecast(posterior, 4)
# workflow with the pipe |>
############################################################
us_fiscal_lsuw |>
specify_bsvar$new() |>
estimate(S = 5) |>
estimate(S = 5) |>
forecast(horizon = 4) -> predictive
# conditional forecasting using a model with exogenous variables
############################################################
specification = specify_bsvar$new(us_fiscal_lsuw, exogenous = us_fiscal_ex)
burn_in = estimate(specification, 5)
posterior = estimate(burn_in, 5)
# forecast 2 years ahead
predictive = forecast(
posterior,
horizon = 8,
exogenous_forecast = us_fiscal_ex_forecasts,
conditional_forecast = us_fiscal_cond_forecasts
)
summary(predictive)
# workflow with the pipe |>
############################################################
us_fiscal_lsuw |>
specify_bsvar$new( exogenous = us_fiscal_ex) |>
estimate(S = 5) |>
estimate(S = 5) |>
forecast(
horizon = 8,
exogenous_forecast = us_fiscal_ex_forecasts,
conditional_forecast = us_fiscal_cond_forecasts
) |> plot()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.