| normalise.PosteriorBSVARMIX | R Documentation |
BNormalises the sign of rows of matrix B MCMC draws,
relative to matrix B_benchmark, provided as the second argument. The implemented
procedure proposed by Waggoner, Zha (2003) normalises the MCMC output in an
optimal way leading to the unimodal posterior. Only normalised MCMC output is
suitable for the computations of the posterior characteristics of the B
matrix elements and their functions such as the impulse response functions and other
economically interpretable values.
## S3 method for class 'PosteriorBSVARMIX'
normalise(posterior, B_benchmark = NULL)
posterior |
posterior estimation outcome of class |
B_benchmark |
the benchmark |
An object of the same class as that provided as the input argument
posterior containing the posterior draws including the draws of the
normalised structural matrix.
Tomasz Woźniak wozniak.tom@pm.me
Waggoner, D.F., and Zha, T., (2003) Likelihood Preserving Normalization in Multiple Equation Models. Journal of Econometrics, 114(2), 329–47, \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/S0304-4076(03)00087-3")}.
estimate
specification = specify_bsvar_mix$new(us_fiscal_lsuw) # specify the model
burn_in = estimate(specification, 5) # run the burn-in
posterior = estimate(burn_in, 5) # estimate the model
# normalise the posterior
BB = posterior$last_draw$starting_values$B # get the last draw of B
B_benchmark = diag((-1) * sign(diag(BB))) %*% BB # set negative diagonal elements
posterior = normalise(posterior, B_benchmark) # draws in posterior are normalised
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.