specify_bsvar_exh: R6 Class representing the specification of the BSVAREXH model...

specify_bsvar_exhR Documentation

R6 Class representing the specification of the BSVAREXH model with exogenous heteroskedastic regime change.

Description

The class BSVAREXH presents complete specification for the BSVAR model with exogenous heteroskedastic regime change.

Public fields

p

a non-negative integer specifying the autoregressive lag order of the model.

identification

an object IdentificationBSVARs with the identifying restrictions.

prior

an object PriorBSVAREXH with the prior specification.

data_matrices

an object DataMatricesBSVAR with the data matrices.

starting_values

an object StartingValuesBSVAREXH with the starting values.

variance_regimes

a T-vector with exogenous regime indicators that are integer numbers associating the time observation with heteroskedastic regime.

Methods

Public methods


BSVAREXH$new()

Create a new specification of the BSVAR model with Markov Switching Heteroskedasticity, BSVAREXH.

Usage
BSVAREXH$new(
  data,
  p = 1L,
  B,
  A,
  distribution = c("norm", "t"),
  exogenous = NULL,
  stationary = rep(FALSE, ncol(data)),
  variance_regimes = NULL
)
Arguments
data

a (T+p)xN matrix with time series data.

p

a positive integer providing model's autoregressive lag order.

B

a logical NxN matrix containing value TRUE for the elements of the structural matrix B to be estimated and value FALSE for exclusion restrictions to be set to zero.

A

a logical NxK matrix containing value TRUE for the elements of the autoregressive matrix A to be estimated and value FALSE for exclusion restrictions to be set to zero.

distribution

a character string specifying the conditional distribution of structural shocks. Value "norm" sets it to the normal distribution, while value "t" sets the Student-t distribution.

exogenous

a (T+p)xd matrix of exogenous variables.

stationary

an N logical vector - its element set to FALSE sets the prior mean for the autoregressive parameters of the Nth equation to the random walk process, otherwise to white noise.

variance_regimes

a T-vector with exogenous regime indicators that are integer numbers associating the time observation with heteroskedastic regime.

Returns

A new complete specification for the bsvar model with exogenous heteroskedastic regime change, BSVAREXH.


BSVAREXH$get_normal()

Returns the logical value of whether the conditional shock distribution is normal.

Usage
BSVAREXH$get_normal()
Examples
spec = specify_bsvar_exh$new(us_fiscal_lsuw)
spec$get_normal()

BSVAREXH$get_data_matrices()

Returns the data matrices as the DataMatricesBSVAR object.

Usage
BSVAREXH$get_data_matrices()
Examples
spec = specify_bsvar_exh$new(us_fiscal_lsuw)
spec$get_data_matrices()

BSVAREXH$get_identification()

Returns the identifying restrictions as the IdentificationBSVARs object.

Usage
BSVAREXH$get_identification()
Examples
spec = specify_bsvar_exh$new(us_fiscal_lsuw)
spec$get_identification()

BSVAREXH$get_prior()

Returns the prior specification as the PriorBSVAREXH object.

Usage
BSVAREXH$get_prior()
Examples
spec = specify_bsvar_exh$new(us_fiscal_lsuw)
spec$get_prior()

BSVAREXH$get_starting_values()

Returns the starting values as the StartingValuesBSVAREXH object.

Usage
BSVAREXH$get_starting_values()
Examples
spec = specify_bsvar_exh$new(us_fiscal_lsuw)
spec$get_starting_values()

BSVAREXH$clone()

The objects of this class are cloneable with this method.

Usage
BSVAREXH$clone(deep = FALSE)
Arguments
deep

Whether to make a deep clone.

See Also

estimate, specify_posterior_bsvar_exh

Examples

spec = specify_bsvar_exh$new(us_fiscal_lsuw)


## ------------------------------------------------
## Method `BSVAREXH$get_normal()`
## ------------------------------------------------

spec = specify_bsvar_exh$new(us_fiscal_lsuw)
spec$get_normal()


## ------------------------------------------------
## Method `BSVAREXH$get_data_matrices()`
## ------------------------------------------------

spec = specify_bsvar_exh$new(us_fiscal_lsuw)
spec$get_data_matrices()


## ------------------------------------------------
## Method `BSVAREXH$get_identification()`
## ------------------------------------------------

spec = specify_bsvar_exh$new(us_fiscal_lsuw)
spec$get_identification()


## ------------------------------------------------
## Method `BSVAREXH$get_prior()`
## ------------------------------------------------

spec = specify_bsvar_exh$new(us_fiscal_lsuw)
spec$get_prior()


## ------------------------------------------------
## Method `BSVAREXH$get_starting_values()`
## ------------------------------------------------

spec = specify_bsvar_exh$new(us_fiscal_lsuw)
spec$get_starting_values()


bsvars documentation built on Aug. 22, 2026, 5:09 p.m.