| specify_bsvar_hmsh | R Documentation |
The class BSVARHMSH presents complete specification for the BSVAR model with Heterogeneous Markov Switching Heteroskedasticity.
pa non-negative integer specifying the autoregressive lag order of the model.
identificationan object IdentificationBSVARs with the identifying restrictions.
prioran object PriorBSVARMSH with the prior specification.
data_matricesan object DataMatricesBSVAR with the data matrices.
starting_valuesan object StartingValuesBSVARHMSH with the starting values.
finiteMa logical value - if true a stationary Markov switching model
is estimated. Otherwise, a sparse Markov switching model is estimated in
which M=20 and the number of visited states is estimated.
BSVARHMSH$new()Create a new specification of the BSVAR model with Heterogeneous Markov Switching Heteroskedasticity, BSVARHMSH.
BSVARHMSH$new(
data,
p = 1L,
M = 2L,
B,
A,
distribution = c("norm", "t"),
exogenous = NULL,
stationary = rep(FALSE, ncol(data)),
finiteM = TRUE
)
dataa (T+p)xN matrix with time series data.
pa positive integer providing model's autoregressive lag order.
Man integer greater than 1 - the number of Markov process' heteroskedastic regimes.
Ba logical NxN matrix containing value TRUE for the
elements of the structural matrix B to be estimated and value FALSE
for exclusion restrictions to be set to zero.
Aa logical NxK matrix containing value TRUE for the elements of
the autoregressive matrix A to be estimated and value FALSE for exclusion restrictions
to be set to zero.
distributiona character string specifying the conditional distribution
of structural shocks. Value "norm" sets it to the normal distribution,
while value "t" sets the Student-t distribution.
exogenousa (T+p)xd matrix of exogenous variables.
stationaryan N logical vector - its element set to FALSE sets
the prior mean for the autoregressive parameters of the Nth equation to the random walk process,
otherwise to white noise.
finiteMa logical value - if true a stationary Markov switching model
is estimated. Otherwise, a sparse Markov switching model is estimated in which
M=20 and the number of visited states is estimated.
A new complete specification for the bsvar model with Heterogeneous Markov Switching Heteroskedasticity, BSVARHMSH.
BSVARHMSH$get_normal()Returns the logical value of whether the conditional shock distribution is normal.
BSVARHMSH$get_normal()
spec = specify_bsvar_hmsh$new(us_fiscal_lsuw) spec$get_normal()
BSVARHMSH$get_data_matrices()Returns the data matrices as the DataMatricesBSVAR object.
BSVARHMSH$get_data_matrices()
spec = specify_bsvar_hmsh$new( data = us_fiscal_lsuw, p = 4, M = 2 ) spec$get_data_matrices()
BSVARHMSH$get_identification()Returns the identifying restrictions as the IdentificationBSVARs object.
BSVARHMSH$get_identification()
spec = specify_bsvar_hmsh$new( data = us_fiscal_lsuw, p = 4, M = 2 ) spec$get_identification()
BSVARHMSH$get_prior()Returns the prior specification as the PriorBSVARMSH object.
BSVARHMSH$get_prior()
spec = specify_bsvar_hmsh$new( data = us_fiscal_lsuw, p = 4, M = 2 ) spec$get_prior()
BSVARHMSH$get_starting_values()Returns the starting values as the StartingValuesBSVARHMSH object.
BSVARHMSH$get_starting_values()
spec = specify_bsvar_hmsh$new( data = us_fiscal_lsuw, p = 4, M = 2 ) spec$get_starting_values()
BSVARHMSH$clone()The objects of this class are cloneable with this method.
BSVARHMSH$clone(deep = FALSE)
deepWhether to make a deep clone.
estimate, specify_posterior_bsvar_hmsh
spec = specify_bsvar_hmsh$new(
data = us_fiscal_lsuw,
p = 4,
M = 2
)
## ------------------------------------------------
## Method `BSVARHMSH$get_normal()`
## ------------------------------------------------
spec = specify_bsvar_hmsh$new(us_fiscal_lsuw)
spec$get_normal()
## ------------------------------------------------
## Method `BSVARHMSH$get_data_matrices()`
## ------------------------------------------------
spec = specify_bsvar_hmsh$new(
data = us_fiscal_lsuw,
p = 4,
M = 2
)
spec$get_data_matrices()
## ------------------------------------------------
## Method `BSVARHMSH$get_identification()`
## ------------------------------------------------
spec = specify_bsvar_hmsh$new(
data = us_fiscal_lsuw,
p = 4,
M = 2
)
spec$get_identification()
## ------------------------------------------------
## Method `BSVARHMSH$get_prior()`
## ------------------------------------------------
spec = specify_bsvar_hmsh$new(
data = us_fiscal_lsuw,
p = 4,
M = 2
)
spec$get_prior()
## ------------------------------------------------
## Method `BSVARHMSH$get_starting_values()`
## ------------------------------------------------
spec = specify_bsvar_hmsh$new(
data = us_fiscal_lsuw,
p = 4,
M = 2
)
spec$get_starting_values()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.