specify_bsvar_sv: R6 Class representing the specification of the BSVAR model...

specify_bsvar_svR Documentation

R6 Class representing the specification of the BSVAR model with Stochastic Volatility heteroskedasticity.

Description

The class BSVARSV presents complete specification for the BSVAR model with Stochastic Volatility heteroskedasticity.

Public fields

p

a non-negative integer specifying the autoregressive lag order of the model.

identification

an object IdentificationBSVARs with the identifying restrictions.

prior

an object PriorBSVARSV with the prior specification.

data_matrices

an object DataMatricesBSVAR with the data matrices.

starting_values

an object StartingValuesBSVARSV with the starting values.

centred_sv

a logical value - if true a centred parameterisation of the Stochastic Volatility process is estimated. Otherwise, its non-centred parameterisation is estimated. See Lütkepohl, Shang, Uzeda, Woźniak (2022) for more info.

Methods

Public methods


BSVARSV$new()

Create a new specification of the BSVAR model with Stochastic Volatility heteroskedasticity, BSVARSV.

Usage
BSVARSV$new(
  data,
  p = 1L,
  B,
  A,
  distribution = c("norm", "t"),
  exogenous = NULL,
  centred_sv = FALSE,
  stationary = rep(FALSE, ncol(data))
)
Arguments
data

a (T+p)xN matrix with time series data.

p

a positive integer providing model's autoregressive lag order.

B

a logical NxN matrix containing value TRUE for the elements of the structural matrix B to be estimated and value FALSE for exclusion restrictions to be set to zero.

A

a logical NxK matrix containing value TRUE for the elements of the autoregressive matrix A to be estimated and value FALSE for exclusion restrictions to be set to zero.

distribution

a character string specifying the conditional distribution of structural shocks. Value "norm" sets it to the normal distribution, while value "t" sets the Student-t distribution.

exogenous

a (T+p)xd matrix of exogenous variables.

centred_sv

a logical value. If FALSE a non-centred Stochastic Volatility processes for conditional variances are estimated. Otherwise, a centred process is estimated.

stationary

an N logical vector - its element set to FALSE sets the prior mean for the autoregressive parameters of the Nth equation to the random walk process, otherwise to white noise.

Returns

A new complete specification for the bsvar model with Stochastic Volatility heteroskedasticity, BSVARSV.


BSVARSV$get_normal()

Returns the logical value of whether the conditional shock distribution is normal.

Usage
BSVARSV$get_normal()
Examples
spec = specify_bsvar_sv$new(us_fiscal_lsuw)
spec$get_normal()

BSVARSV$get_data_matrices()

Returns the data matrices as the DataMatricesBSVAR object.

Usage
BSVARSV$get_data_matrices()
Examples
data(us_fiscal_lsuw)
spec = specify_bsvar_sv$new(
   data = us_fiscal_lsuw,
   p = 4
)
spec$get_data_matrices()

BSVARSV$get_identification()

Returns the identifying restrictions as the IdentificationBSVARs object.

Usage
BSVARSV$get_identification()
Examples
data(us_fiscal_lsuw)
spec = specify_bsvar_sv$new(
   data = us_fiscal_lsuw,
   p = 4
)
spec$get_identification()

BSVARSV$get_prior()

Returns the prior specification as the PriorBSVARSV object.

Usage
BSVARSV$get_prior()
Examples
data(us_fiscal_lsuw)
spec = specify_bsvar_sv$new(
   data = us_fiscal_lsuw,
   p = 4
)
spec$get_prior()

BSVARSV$get_starting_values()

Returns the starting values as the StartingValuesBSVARSV object.

Usage
BSVARSV$get_starting_values()
Examples
data(us_fiscal_lsuw)
spec = specify_bsvar_sv$new(
   data = us_fiscal_lsuw,
   p = 4
)
spec$get_starting_values()

BSVARSV$clone()

The objects of this class are cloneable with this method.

Usage
BSVARSV$clone(deep = FALSE)
Arguments
deep

Whether to make a deep clone.

See Also

estimate, specify_posterior_bsvar_sv

Examples

data(us_fiscal_lsuw)
spec = specify_bsvar_sv$new(
   data = us_fiscal_lsuw,
   p = 4
)


## ------------------------------------------------
## Method `BSVARSV$get_normal()`
## ------------------------------------------------

spec = specify_bsvar_sv$new(us_fiscal_lsuw)
spec$get_normal()


## ------------------------------------------------
## Method `BSVARSV$get_data_matrices()`
## ------------------------------------------------

data(us_fiscal_lsuw)
spec = specify_bsvar_sv$new(
   data = us_fiscal_lsuw,
   p = 4
)
spec$get_data_matrices()


## ------------------------------------------------
## Method `BSVARSV$get_identification()`
## ------------------------------------------------

data(us_fiscal_lsuw)
spec = specify_bsvar_sv$new(
   data = us_fiscal_lsuw,
   p = 4
)
spec$get_identification()


## ------------------------------------------------
## Method `BSVARSV$get_prior()`
## ------------------------------------------------

data(us_fiscal_lsuw)
spec = specify_bsvar_sv$new(
   data = us_fiscal_lsuw,
   p = 4
)
spec$get_prior()


## ------------------------------------------------
## Method `BSVARSV$get_starting_values()`
## ------------------------------------------------

data(us_fiscal_lsuw)
spec = specify_bsvar_sv$new(
   data = us_fiscal_lsuw,
   p = 4
)
spec$get_starting_values()


bsvars documentation built on Aug. 22, 2026, 5:09 p.m.