| specify_identification_bsvars | R Documentation |
The class IdentificationBSVARs presents the identifying restrictions for the bsvar models.
VBa list of N matrices determining the unrestricted elements of matrix B.
VAa list of N matrices determining the unrestricted elements of matrix A.
IdentificationBSVARs$new()Create new identifying restrictions IdentificationBSVARs.
IdentificationBSVARs$new(B, A, N, K)
Ba logical NxN matrix containing value TRUE for the elements of
the structural matrix B to be estimated and value FALSE for exclusion restrictions
to be set to zero.
Aa logical NxK matrix containing value TRUE for the elements of
the autoregressive matrix A to be estimated and value FALSE for exclusion restrictions
to be set to zero.
Na positive integer - the number of dependent variables in the model.
Ka positive integer - the number of parameters in a row of autoregressive matrix.
Identifying restrictions IdentificationBSVARs.
IdentificationBSVARs$get_identification()Returns the elements of the identification pattern IdentificationBSVARs as a list.
IdentificationBSVARs$get_identification()
B = matrix(c(TRUE,TRUE,TRUE,FALSE,FALSE,TRUE,FALSE,TRUE,TRUE), 3, 3); B spec = specify_identification_bsvars$new(B = B, N = 3, K = 4) spec$get_identification()
IdentificationBSVARs$set_identification()Set new starting values StartingValuesBSVAR.
IdentificationBSVARs$set_identification(B, A, N, K)
Ba logical NxN matrix containing value TRUE for the elements of
the structural matrix B to be estimated and value FALSE for exclusion restrictions
to be set to zero.
Aa logical NxK matrix containing value TRUE for the elements of
the autoregressive matrix A to be estimated and value FALSE for exclusion restrictions
to be set to zero.
Na positive integer - the number of dependent variables in the model.
Ka positive integer - the number of parameters in a row of autoregressive matrix.
spec = specify_identification_bsvars$new(N = 3, K = 4) # specify a model with the default option B = matrix(c(TRUE,TRUE,TRUE,FALSE,FALSE,TRUE,FALSE,TRUE,TRUE), 3, 3); B spec$set_identification(B = B, N = 3, K = 4) # modify an existing specification spec$get_identification() # check the outcome
IdentificationBSVARs$clone()The objects of this class are cloneable with this method.
IdentificationBSVARs$clone(deep = FALSE)
deepWhether to make a deep clone.
specify_identification_bsvars$new(N = 3, K = 4) # recursive specification for a 3-variable system
B = matrix(c(TRUE,TRUE,TRUE,FALSE,FALSE,TRUE,FALSE,TRUE,TRUE), 3, 3); B
specify_identification_bsvars$new(B = B, N = 3, K = 4) # an alternative identification pattern
## ------------------------------------------------
## Method `IdentificationBSVARs$get_identification()`
## ------------------------------------------------
B = matrix(c(TRUE,TRUE,TRUE,FALSE,FALSE,TRUE,FALSE,TRUE,TRUE), 3, 3); B
spec = specify_identification_bsvars$new(B = B, N = 3, K = 4)
spec$get_identification()
## ------------------------------------------------
## Method `IdentificationBSVARs$set_identification()`
## ------------------------------------------------
spec = specify_identification_bsvars$new(N = 3, K = 4) # specify a model with the default option
B = matrix(c(TRUE,TRUE,TRUE,FALSE,FALSE,TRUE,FALSE,TRUE,TRUE), 3, 3); B
spec$set_identification(B = B, N = 3, K = 4) # modify an existing specification
spec$get_identification() # check the outcome
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.