The class PriorBSVART presents a prior specification for the bsvar model with t-distributed structural shocks.
bsvars::PriorBSVAR -> PriorBSVART
Aan NxK matrix, the mean of the normal prior distribution
for the parameter matrix \(A\).
A_V_inva KxK precision matrix of the normal prior
distribution for each of the row of the parameter matrix \(A\). This
precision matrix is equation invariant.
B_V_invan NxN precision matrix of the generalised-normal
prior distribution for the structural matrix \(B\). This precision
matrix is equation invariant.
B_nua positive integer greater of equal than N, a shape
parameter of the generalised-normal prior distribution for the structural
matrix \(B\).
hyper_nu_Ba positive scalar, the shape parameter of the inverted-gamma 2 prior for the overall shrinkage parameter for matrix \(B\).
hyper_a_Ba positive scalar, the shape parameter of the gamma prior for the second-level hierarchy for the overall shrinkage parameter for matrix \(B\).
hyper_s_BBa positive scalar, the scale parameter of the inverted-gamma 2 prior for the third-level of hierarchy for overall shrinkage parameter for matrix \(B\).
hyper_nu_BBa positive scalar, the shape parameter of the inverted-gamma 2 prior for the third-level of hierarchy for overall shrinkage parameter for matrix \(B\).
hyper_nu_Aa positive scalar, the shape parameter of the inverted-gamma 2 prior for the overall shrinkage parameter for matrix \(A\).
hyper_a_Aa positive scalar, the shape parameter of the gamma prior for the second-level hierarchy for the overall shrinkage parameter for matrix \(A\).
hyper_s_AAa positive scalar, the scale parameter of the inverted-gamma 2 prior for the third-level of hierarchy for overall shrinkage parameter for matrix \(A\).
hyper_nu_AAa positive scalar, the shape parameter of the inverted-gamma 2 prior for the third-level of hierarchy for overall shrinkage parameter for matrix \(A\).
prior = specify_prior_bsvar_t$new(N = 3, p = 1) # specify the prior
prior$A # show autoregressive prior mean
Run the code above in your browser using DataLab