| specify_starting_values_bsvar | R Documentation |
The class StartingValuesBSVAR presents starting values for the homoskedastic bsvar model.
Aan NxK matrix of starting values for the parameter A.
Ban NxN matrix of starting values for the parameter B.
hypera (2*N+1)x2 matrix of starting values for the shrinkage hyper-parameters of the
hierarchical prior distribution.
lambdaa NxT matrix of starting values for latent variables.
dfan Nx1 vector of positive numbers with starting values
for the equation-specific degrees of freedom parameters of the Student-t
conditional distribution of structural shocks.
StartingValuesBSVAR$new()Create new starting values StartingValuesBSVAR.
StartingValuesBSVAR$new(A, B, N, T, p, d = 0)
Aa logical NxK matrix containing value TRUE for the elements of
the autoregressive matrix A to be estimated and value FALSE for exclusion restrictions
to be set to zero.
Ba logical NxN matrix containing value TRUE for the elements of
the staructural matrix B to be estimated and value FALSE for exclusion restrictions
to be set to zero.
Na positive integer - the number of dependent variables in the model.
Ta positive integer - the number of time periods in the data.
pa positive integer - the autoregressive lag order of the SVAR model.
da positive integer - the number of exogenous variables in the model.
Starting values StartingValuesBSVAR.
# starting values for a homoskedastic bsvar with 4 lags for a 3-variable system A = matrix(TRUE, 3, 13) B = matrix(TRUE, 3, 3) sv = specify_starting_values_bsvar$new(A = A, B = B, N = 3, T = 120, p = 4)
StartingValuesBSVAR$get_starting_values()Returns the elements of the starting values StartingValuesBSVAR as a list.
StartingValuesBSVAR$get_starting_values()
# starting values for a homoskedastic bsvar with 1 lag for a 3-variable system A = matrix(TRUE, 3, 4) B = matrix(TRUE, 3, 3) sv = specify_starting_values_bsvar$new(A = A, B = B, N = 3, T = 120, p = 1) sv$get_starting_values() # show starting values as list
StartingValuesBSVAR$set_starting_values()Returns the elements of the starting values StartingValuesBSVAR as a list.
StartingValuesBSVAR$set_starting_values(last_draw)
last_drawa list containing the last draw of elements B - an NxN matrix,
A - an NxK matrix, and hyper - a vector of 5 positive real numbers.
An object of class StartingValuesBSVAR including the last draw of the current MCMC
as the starting value to be passed to the continuation of the MCMC estimation using estimate().
# starting values for a homoskedastic bsvar with 1 lag for a 3-variable system A = matrix(TRUE, 3, 4) B = matrix(TRUE, 3, 3) sv = specify_starting_values_bsvar$new(A = A, B = B, N = 3, T = 120, p = 1) # Modify the starting values by: sv_list = sv$get_starting_values() # getting them as list sv_list$A <- matrix(rnorm(12), 3, 4) # modifying the entry sv$set_starting_values(sv_list) # providing to the class object
StartingValuesBSVAR$clone()The objects of this class are cloneable with this method.
StartingValuesBSVAR$clone(deep = FALSE)
deepWhether to make a deep clone.
# starting values for a homoskedastic bsvar for a 3-variable system
A = matrix(TRUE, 3, 4)
B = matrix(TRUE, 3, 3)
sv = specify_starting_values_bsvar$new(A = A, B = B, N = 3, T = 120, p = 1)
## ------------------------------------------------
## Method `StartingValuesBSVAR$new()`
## ------------------------------------------------
# starting values for a homoskedastic bsvar with 4 lags for a 3-variable system
A = matrix(TRUE, 3, 13)
B = matrix(TRUE, 3, 3)
sv = specify_starting_values_bsvar$new(A = A, B = B, N = 3, T = 120, p = 4)
## ------------------------------------------------
## Method `StartingValuesBSVAR$get_starting_values()`
## ------------------------------------------------
# starting values for a homoskedastic bsvar with 1 lag for a 3-variable system
A = matrix(TRUE, 3, 4)
B = matrix(TRUE, 3, 3)
sv = specify_starting_values_bsvar$new(A = A, B = B, N = 3, T = 120, p = 1)
sv$get_starting_values() # show starting values as list
## ------------------------------------------------
## Method `StartingValuesBSVAR$set_starting_values()`
## ------------------------------------------------
# starting values for a homoskedastic bsvar with 1 lag for a 3-variable system
A = matrix(TRUE, 3, 4)
B = matrix(TRUE, 3, 3)
sv = specify_starting_values_bsvar$new(A = A, B = B, N = 3, T = 120, p = 1)
# Modify the starting values by:
sv_list = sv$get_starting_values() # getting them as list
sv_list$A <- matrix(rnorm(12), 3, 4) # modifying the entry
sv$set_starting_values(sv_list) # providing to the class object
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.