| specify_starting_values_bsvar_exh | R Documentation |
The class StartingValuesBSVAREXH presents starting values for the bsvar model with exogenous regime change Heteroskedasticity.
StartingValuesBSVAR -> StartingValuesBSVAREXH
Aan NxK matrix of starting values for the parameter A.
Ban NxN matrix of starting values for the parameter B.
hypera (2*N+1)x2 matrix of starting values for the shrinkage hyper-parameters of the
hierarchical prior distribution.
sigma2an NxM matrix of starting values for the regime-specific
variances of the structural shocks. Its elements sum to value M over the rows.
xian MxT matrix of starting values for the Markov process
indicator. Its columns are a chosen column of an identity matrix of order M.
lambdaa NxT matrix of starting values for latent variables.
dfan Nx1 vector of positive numbers with starting values
for the equation-specific degrees of freedom parameters of the Student-t
conditional distribution of structural shocks.
StartingValuesBSVAREXH$new()Create new starting values StartingValuesBSVAREXH.
StartingValuesBSVAREXH$new(A, B, N, p, T, d = 0, variance_regimes = rep(1, T))
Aa logical NxK matrix containing value TRUE for the elements of
the autoregressive matrix A to be estimated and value FALSE for exclusion restrictions
to be set to zero.
Ba logical NxN matrix containing value TRUE for the elements of
the structural matrix B to be estimated and value FALSE for exclusion restrictions
to be set to zero.
Na positive integer - the number of dependent variables in the model.
pa positive integer - the autoregressive lag order of the SVAR model.
Ta positive integer - the the time series dimension of the dependent
variable matrix Y.
da positive integer - the number of exogenous variables in the model.
variance_regimesa T-vector with exogenous regime indicators that are integer
numbers associating the time observation with heteroskedastic regime.
Starting values StartingValuesBSVAREXH.
StartingValuesBSVAREXH$get_starting_values()Returns the elements of the starting values StartingValuesBSVAR-MS as a list.
StartingValuesBSVAREXH$get_starting_values()
# starting values for a homoskedastic bsvar with 1 lag for a 3-variable system A = matrix(TRUE, 3, 4) B = matrix(TRUE, 3, 3) sv = specify_starting_values_bsvar_exh$new(A = A, B = B, N = 3, p = 1, T = 100) sv$get_starting_values() # show starting values as list
StartingValuesBSVAREXH$set_starting_values()Returns the elements of the starting values StartingValuesBSVAREXH as a list.
StartingValuesBSVAREXH$set_starting_values(last_draw)
last_drawa list containing the last draw.
An object of class StartingValuesBSVAREXH including the last draw
of the current MCMC as the starting value to be passed to the continuation
of the MCMC estimation using estimate().
# starting values for a bsvar model with 1 lag for a 3-variable system A = matrix(TRUE, 3, 4) B = matrix(TRUE, 3, 3) sv = specify_starting_values_bsvar_exh$new(A = A, B = B, N = 3, p = 1, T = 100) # Modify the starting values by: sv_list = sv$get_starting_values() # getting them as list sv_list$A <- matrix(rnorm(12), 3, 4) # modifying the entry sv$set_starting_values(sv_list) # providing to the class object
StartingValuesBSVAREXH$clone()The objects of this class are cloneable with this method.
StartingValuesBSVAREXH$clone(deep = FALSE)
deepWhether to make a deep clone.
# starting values for a bsvar model for a 3-variable system
A = matrix(TRUE, 3, 4)
B = matrix(TRUE, 3, 3)
sv = specify_starting_values_bsvar_exh$new(A = A, B = B, N = 3, p = 1, T = 100)
## ------------------------------------------------
## Method `StartingValuesBSVAREXH$get_starting_values()`
## ------------------------------------------------
# starting values for a homoskedastic bsvar with 1 lag for a 3-variable system
A = matrix(TRUE, 3, 4)
B = matrix(TRUE, 3, 3)
sv = specify_starting_values_bsvar_exh$new(A = A, B = B, N = 3, p = 1, T = 100)
sv$get_starting_values() # show starting values as list
## ------------------------------------------------
## Method `StartingValuesBSVAREXH$set_starting_values()`
## ------------------------------------------------
# starting values for a bsvar model with 1 lag for a 3-variable system
A = matrix(TRUE, 3, 4)
B = matrix(TRUE, 3, 3)
sv = specify_starting_values_bsvar_exh$new(A = A, B = B, N = 3, p = 1, T = 100)
# Modify the starting values by:
sv_list = sv$get_starting_values() # getting them as list
sv_list$A <- matrix(rnorm(12), 3, 4) # modifying the entry
sv$set_starting_values(sv_list) # providing to the class object
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.