| specify_starting_values_bsvar_hmsh | R Documentation |
The class StartingValuesBSVARHMSH presents starting values for the bsvar model with Heterogeneous Markov Switching Heteroskedasticity.
StartingValuesBSVAR -> StartingValuesBSVARHMSH
Aan NxK matrix of starting values for the parameter A.
Ban NxN matrix of starting values for the parameter B.
hypera (2*N+1)x2 matrix of starting values for the shrinkage
hyper-parameters of the hierarchical prior distribution.
sigma2an NxM matrix of starting values for the MS
state-specific variances of the structural shocks. Its elements sum to
value M over the rows.
PR_TRan MxMxN array of starting values for the transition
probability matrix of the Markov process. Its elements sum to 1 over the rows.
xian MxTxN array of starting values for the Markov process
indicator. Its columns are a chosen column of an identity matrix of order M.
pi_0an MxN matrix of starting values for state probability at
time t=0. Its elements sum to 1 in columns.
lambdaa NxT matrix of starting values for latent variables.
dfan Nx1 vector of positive numbers with starting values
for the equation-specific degrees of freedom parameters of the Student-t
conditional distribution of structural shocks.
StartingValuesBSVARHMSH$new()Create new starting values StartingValuesBSVARHMSH.
StartingValuesBSVARHMSH$new(A, B, N, p, M, T, d = 0, finiteM = TRUE)
Aa logical NxK matrix containing value TRUE for the elements of
the autoregressive matrix A to be estimated and value FALSE for exclusion restrictions
to be set to zero.
Ba logical NxN matrix containing value TRUE for the elements of
the structural matrix B to be estimated and value FALSE for exclusion restrictions
to be set to zero.
Na positive integer - the number of dependent variables in the model.
pa positive integer - the autoregressive lag order of the SVAR model.
Man integer greater than 1 - the number of Markov process' heteroskedastic regimes.
Ta positive integer - the the time series dimension of the dependent variable matrix Y.
da positive integer - the number of exogenous variables in the model.
finiteMa logical value - if true a stationary Markov switching model
is estimated. Otherwise, a sparse Markov switching model is estimated in which
M=20 and the number of visited states is estimated.
Starting values StartingValuesBSVARHMSH.
StartingValuesBSVARHMSH$get_starting_values()Returns the elements of the starting values StartingValuesBSVARHMSH as a list.
StartingValuesBSVARHMSH$get_starting_values()
# starting values for a homoskedastic bsvar with 1 lag for a 3-variable system A = matrix(TRUE, 3, 4) B = matrix(TRUE, 3, 3) sv = specify_starting_values_bsvar_hmsh$new(A = A, B = B, N = 3, p = 1, M = 2, T = 100) sv$get_starting_values() # show starting values as list
StartingValuesBSVARHMSH$set_starting_values()Returns the elements of the starting values StartingValuesBSVARHMSH as a list.
StartingValuesBSVARHMSH$set_starting_values(last_draw)
last_drawa list containing the last draw.
An object of class StartingValuesBSVARHMSH including the last draw
of the current MCMC as the starting value to be passed to the continuation
of the MCMC estimation using estimate().
# starting values for a bsvar model with 1 lag for a 3-variable system A = matrix(TRUE, 3, 4) B = matrix(TRUE, 3, 3) sv = specify_starting_values_bsvar_hmsh$new(A = A, B = B, N = 3, p = 1, M = 2, T = 100) # Modify the starting values by: sv_list = sv$get_starting_values() # getting them as list sv_list$A <- matrix(rnorm(12), 3, 4) # modifying the entry sv$set_starting_values(sv_list) # providing to the class object
StartingValuesBSVARHMSH$clone()The objects of this class are cloneable with this method.
StartingValuesBSVARHMSH$clone(deep = FALSE)
deepWhether to make a deep clone.
# starting values for a bsvar model for a 3-variable system
A = matrix(TRUE, 3, 4)
B = matrix(TRUE, 3, 3)
sv = specify_starting_values_bsvar_hmsh$new(A = A, B = B, N = 3, p = 1, M = 2, T = 100)
## ------------------------------------------------
## Method `StartingValuesBSVARHMSH$get_starting_values()`
## ------------------------------------------------
# starting values for a homoskedastic bsvar with 1 lag for a 3-variable system
A = matrix(TRUE, 3, 4)
B = matrix(TRUE, 3, 3)
sv = specify_starting_values_bsvar_hmsh$new(A = A, B = B, N = 3, p = 1, M = 2, T = 100)
sv$get_starting_values() # show starting values as list
## ------------------------------------------------
## Method `StartingValuesBSVARHMSH$set_starting_values()`
## ------------------------------------------------
# starting values for a bsvar model with 1 lag for a 3-variable system
A = matrix(TRUE, 3, 4)
B = matrix(TRUE, 3, 3)
sv = specify_starting_values_bsvar_hmsh$new(A = A, B = B, N = 3, p = 1, M = 2, T = 100)
# Modify the starting values by:
sv_list = sv$get_starting_values() # getting them as list
sv_list$A <- matrix(rnorm(12), 3, 4) # modifying the entry
sv$set_starting_values(sv_list) # providing to the class object
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.