| specify_starting_values_bsvar_mix | R Documentation |
The class StartingValuesBSVARMIX presents starting values for the bsvar model with a zero-mean mixture of normals model for structural shocks.
StartingValuesBSVAR -> StartingValuesBSVARMSH -> StartingValuesBSVARMIX
Aan NxK matrix of starting values for the parameter A.
Ban NxN matrix of starting values for the parameter B.
hypera (2*N+1)x2 matrix of starting values for the shrinkage hyper-parameters of the
hierarchical prior distribution.
sigma2an NxM matrix of starting values for the MS state-specific variances of the structural shocks. Its elements sum to value M over the rows.
PR_TRan MxM matrix of starting values for the probability matrix of the Markov process. Its rows must be identical and the elements of each row sum to 1 over the rows.
xian MxT matrix of starting values for the Markov process indicator. Its columns are a chosen column of an identity matrix of order M.
pi_0an M-vector of starting values for mixture components state probabilities. Its elements sum to 1.
lambdaa NxT matrix of starting values for latent variables.
dfan Nx1 vector of positive numbers with starting values
for the equation-specific degrees of freedom parameters of the Student-t
conditional distribution of structural shocks.
StartingValuesBSVARMSH$get_starting_values()StartingValuesBSVARMSH$set_starting_values()StartingValuesBSVARMIX$new()Create new starting values StartingValuesBSVARMIX.
StartingValuesBSVARMIX$new(A, B, N, p, M, T, d = 0, finiteM = TRUE)
Aa logical NxK matrix containing value TRUE for the elements of
the autoregressive matrix A to be estimated and value FALSE for exclusion restrictions
to be set to zero.
Ba logical NxN matrix containing value TRUE for the elements of
the staructural matrix B to be estimated and value FALSE for exclusion restrictions
to be set to zero.
Na positive integer - the number of dependent variables in the model.
pa positive integer - the autoregressive lag order of the SVAR model.
Man integer greater than 1 - the number of components of the mixture of normals.
Ta positive integer - the the time series dimension of the dependent variable matrix Y.
da positive integer - the number of exogenous variables in the model.
finiteMa logical value - if true a finite mixture model is estimated. Otherwise, a sparse mixture model is estimated in which M=20 and the number of visited states is estimated.
Starting values StartingValuesBSVARMIX.
StartingValuesBSVARMIX$clone()The objects of this class are cloneable with this method.
StartingValuesBSVARMIX$clone(deep = FALSE)
deepWhether to make a deep clone.
# starting values for a bsvar model for a 3-variable system
A = matrix(TRUE, 3, 4)
B = matrix(TRUE, 3, 3)
sv = specify_starting_values_bsvar_mix$new(A = A, B = B, N = 3, p = 1, M = 2, T = 100)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.