summary.Forecasts: Provides posterior summary of Forecasts

View source: R/summary.R

summary.ForecastsR Documentation

Provides posterior summary of Forecasts

Description

Provides posterior summary of the forecasts including their mean, standard deviations, as well as 5 and 95 percentiles.

Usage

## S3 method for class 'Forecasts'
summary(object, ...)

Arguments

object

an object of class Forecasts obtained using the forecast() function containing draws the predictive density.

...

additional arguments affecting the summary produced.

Value

A list reporting the posterior mean, standard deviations, as well as 5 and 95 percentiles of the forecasts for each of the variables and forecast horizons.

Author(s)

Tomasz Woźniak wozniak.tom@pm.me

See Also

forecast

Examples

specification  = specify_bsvar$new(us_fiscal_lsuw)
burn_in        = estimate(specification, 5)
posterior      = estimate(burn_in, 5)

# forecast
fore           = forecast(posterior, horizon = 2)
fore_summary   = summary(fore)
fore_summary$variable1

# workflow with the pipe |>
############################################################
us_fiscal_lsuw |>
  specify_bsvar$new() |>
  estimate(S = 5) |> 
  estimate(S = 5) |> 
  forecast(horizon = 2) |>
  summary() -> fore_summary
fore_summary$variable1


bsvars documentation built on Aug. 22, 2026, 5:09 p.m.