summary.PosteriorFitted: Provides posterior summary of variables' fitted values

View source: R/summary.R

summary.PosteriorFittedR Documentation

Provides posterior summary of variables' fitted values

Description

Provides posterior summary of the fitted values including their mean, standard deviations, as well as 5 and 95 percentiles.

Usage

## S3 method for class 'PosteriorFitted'
summary(object, ...)

Arguments

object

an object of class PosteriorFitted obtained using the compute_fitted_values() function containing draws the predictive density of the sample data.

...

additional arguments affecting the summary produced.

Value

A list reporting the posterior mean, standard deviations, as well as 5 and 95 percentiles of the fitted values for each of the shocks and periods.

Author(s)

Tomasz Woźniak wozniak.tom@pm.me

See Also

compute_fitted_values

Examples

specification  = specify_bsvar$new(us_fiscal_lsuw)
burn_in        = estimate(specification, 5)
posterior      = estimate(burn_in, 5)

# compute fitted values
fitted         = compute_fitted_values(posterior)
fitted_summary = summary(fitted)
fitted_summary$ttr[,1] # access posterior mean of ttr

# workflow with the pipe |>
############################################################
us_fiscal_lsuw |>
  specify_bsvar$new() |>
  estimate(S = 5) |> 
  estimate(S = 5) |> 
  compute_fitted_values() |>
  summary() -> fitted_summary
fitted_summary$ttr[,1] # access posterior mean of ttr


bsvars documentation built on Aug. 22, 2026, 5:09 p.m.