summary.PosteriorIR: Provides posterior summary of impulse responses

View source: R/summary.R

summary.PosteriorIRR Documentation

Provides posterior summary of impulse responses

Description

Provides posterior summary of the impulse responses of each variable to each of the shocks at all horizons. Includes their posterior means, standard deviations, as well as 5 and 95 percentiles.

Usage

## S3 method for class 'PosteriorIR'
summary(object, ...)

Arguments

object

an object of class PosteriorIR obtained using the compute_impulse_responses() function containing draws from the posterior distribution of the impulse responses.

...

additional arguments affecting the summary produced.

Value

A list reporting the posterior mean, standard deviations, as well as 5 and 95 percentiles of the impulse responses of each variable to each of the shocks at all horizons.

Author(s)

Tomasz Woźniak wozniak.tom@pm.me

See Also

compute_impulse_responses

Examples

specification  = specify_bsvar$new(us_fiscal_lsuw)
burn_in        = estimate(specification, 5)
posterior      = estimate(burn_in, 5)

# compute impulse responses
irf            = compute_impulse_responses(posterior, horizon = 4)
irf_summary    = summary(irf)
irf_summary$shock1 # inspect IRFs of the first shock

# workflow with the pipe |>
############################################################
set.seed(123)
us_fiscal_lsuw |>
  specify_bsvar$new() |>
  estimate(S = 5) |> 
  estimate(S = 5) |> 
  compute_impulse_responses(horizon = 4) |>
  summary() -> irf_summary
irf_summary$shock1 # inspect IRFs of the first shock


bsvars documentation built on Aug. 22, 2026, 5:09 p.m.