summary.PosteriorRegimePr: Provides posterior summary of regime probabilities

View source: R/summary.R

summary.PosteriorRegimePrR Documentation

Provides posterior summary of regime probabilities

Description

Provides posterior summary of regime probabilities including their mean, standard deviations, as well as 5 and 95 percentiles.

Usage

## S3 method for class 'PosteriorRegimePr'
summary(object, ...)

Arguments

object

an object of class PosteriorRegimePr obtained using the compute_regime_probabilities() function containing posterior draws of regime allocations.

...

additional arguments affecting the summary produced.

Value

A list reporting the posterior mean and standard deviations of the regime probabilities.

Author(s)

Tomasz Woźniak wozniak.tom@pm.me

See Also

compute_regime_probabilities

Examples

specification  = specify_bsvar_msh$new(us_fiscal_lsuw)
burn_in        = estimate(specification, 5)
posterior      = estimate(burn_in, 5)

# compute regime probabilities
rp             = compute_regime_probabilities(posterior)
rp_summary     = summary(rp)
head(rp_summary$MarkovProcess1$regime1) # browse the results

# workflow with the pipe |>
############################################################
us_fiscal_lsuw |>
  specify_bsvar_msh$new() |>
  estimate(S = 5) |> 
  estimate(S = 5) |> 
  compute_regime_probabilities() |>
  summary() -> rp_summary
head(rp_summary$MarkovProcess1$regime1) # browse the results


bsvars documentation built on Aug. 22, 2026, 5:09 p.m.