summary.PosteriorShocks: Provides posterior summary of structural shocks

View source: R/summary.R

summary.PosteriorShocksR Documentation

Provides posterior summary of structural shocks

Description

Provides posterior summary of the structural shocks including their mean, standard deviations, as well as 5 and 95 percentiles.

Usage

## S3 method for class 'PosteriorShocks'
summary(object, ...)

Arguments

object

an object of class PosteriorShocks obtained using the compute_structural_shocks() function containing draws the posterior distribution of the structural shocks.

...

additional arguments affecting the summary produced.

Value

A list reporting the posterior mean, standard deviations, as well as 5 and 95 percentiles of the structural shocks for each of the equations and periods.

Author(s)

Tomasz Woźniak wozniak.tom@pm.me

See Also

compute_structural_shocks

Examples

specification  = specify_bsvar$new(us_fiscal_lsuw)
burn_in        = estimate(specification, 5)
posterior      = estimate(burn_in, 5)

# compute structural shocks
shocks         = compute_structural_shocks(posterior)
shocks_summary = summary(shocks)
head(shocks_summary$shock1)

# workflow with the pipe |>
############################################################
set.seed(123)
us_fiscal_lsuw |>
  specify_bsvar$new() |>
  estimate(S = 5) |> 
  estimate(S = 5) |> 
  compute_structural_shocks() |>
  summary() -> shocks_summary
head(shocks_summary$shock1)


bsvars documentation built on Aug. 22, 2026, 5:09 p.m.