| summary.SDDRidMIX | R Documentation |
Provides summary of the Savage-Dickey density ratios for verification of structural shocks normality. The outcomes can be used to make probabilistic statements about identification through non-normality.
## S3 method for class 'SDDRidMIX'
summary(object, ...)
object |
an object of class |
... |
additional arguments affecting the summary produced. |
A table reporting the logarithm of Bayes factors of normal to
non-normal shocks posterior odds "log(SDDR)" for each structural shock,
their numerical standard errors "NSE", and the implied posterior
probability of the normality and non-normality hypothesis,
"Pr[normal|data]" and "Pr[non-normal|data]"
respectively.
Tomasz Woźniak wozniak.tom@pm.me
verify_identification.PosteriorBSVARMIX
specification = specify_bsvar_mix$new(us_fiscal_lsuw, M = 2)
posterior = estimate(specification, 10)
# verify heteroskedasticity
sddr = verify_identification(posterior)
summary(sddr)
# workflow with the pipe |>
############################################################
us_fiscal_lsuw |>
specify_bsvar_mix$new(M = 2) |>
estimate(S = 10) |>
verify_identification() |>
summary() -> sddr_summary
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.