View source: R/compute_conditional_sd.R
| compute_conditional_sd.PosteriorBSVARMIX | R Documentation |
Each of the draws from the posterior estimation of models is transformed into a draw from the posterior distribution of the structural shock conditional standard deviations.
## S3 method for class 'PosteriorBSVARMIX'
compute_conditional_sd(posterior)
posterior |
posterior estimation outcome - an object of class
|
An object of class PosteriorSigma, that is, an NxTxS
array with attribute PosteriorSigma containing S draws of the
structural shock conditional standard deviations.
Tomasz Woźniak wozniak.tom@pm.me
estimate, normalise, summary
specification = specify_bsvar_mix$new(us_fiscal_lsuw, M = 2)
burn_in = estimate(specification, 5)
posterior = estimate(burn_in, 5)
csd = compute_conditional_sd(posterior)
# workflow with the pipe |>
############################################################
us_fiscal_lsuw |>
specify_bsvar_mix$new(M = 2) |>
estimate(S = 5) |>
estimate(S = 5) |>
compute_conditional_sd() -> csd
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.