View source: R/compute_impulse_responses.R
| compute_impulse_responses.PosteriorBSVARHMSH | R Documentation |
Each of the draws from the posterior estimation of models from packages bsvars or bsvarSIGNs is transformed into a draw from the posterior distribution of the impulse responses.
## S3 method for class 'PosteriorBSVARHMSH'
compute_impulse_responses(posterior, horizon, standardise = FALSE)
posterior |
posterior estimation outcome - an object of class
|
horizon |
a positive integer number denoting the forecast horizon for the impulse responses computations. |
standardise |
a logical value. If |
An object of class PosteriorIR, that is, an NxNx(horizon+1)xS array with attribute PosteriorIR
containing S draws of the impulse responses.
Tomasz Woźniak wozniak.tom@pm.me
Kilian, L., & Lütkepohl, H. (2017). Structural VAR Tools, Chapter 4, In: Structural vector autoregressive analysis. Cambridge University Press.
estimate, normalise, summary
specification = specify_bsvar_hmsh$new(us_fiscal_lsuw)
burn_in = estimate(specification, 5)
posterior = estimate(burn_in, 5)
# compute impulse responses 2 years ahead
irf = compute_impulse_responses(posterior, horizon = 8)
# workflow with the pipe |>
############################################################
us_fiscal_lsuw |>
specify_bsvar_msh$new() |>
estimate(S = 5) |>
estimate(S = 5) |>
compute_impulse_responses(horizon = 4) -> irfs
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.