| specify_bsvar | R Documentation |
The class BSVAR presents complete specification for the homoskedastic bsvar model.
pa non-negative integer specifying the autoregressive lag order of the model.
identificationan object IdentificationBSVAR with the identifying restrictions.
prioran object PriorBSVAR with the prior specification.
data_matricesan object DataMatricesBSVAR with the data matrices.
starting_valuesan object StartingValuesBSVAR with the starting values.
BSVAR$new()Create a new specification of the homoskedastic bsvar model BSVAR.
BSVAR$new(
data,
p = 1L,
B,
A,
distribution = c("norm", "t"),
exogenous = NULL,
stationary = rep(FALSE, ncol(data))
)
dataa (T+p)xN matrix with time series data.
pa positive integer providing model's autoregressive lag order.
Ba logical NxN matrix containing value TRUE for the elements of
the structural matrix B to be estimated and value FALSE for exclusion restrictions
to be set to zero.
Aa logical NxK matrix containing value TRUE for the elements of
the autoregressive matrix A to be estimated and value FALSE for exclusion restrictions
to be set to zero.
distributiona character string specifying the conditional distribution
of structural shocks. Value "norm" sets it to the normal distribution,
while value "t" sets the Student-t distribution.
exogenousa (T+p)xd matrix of exogenous variables.
stationaryan N logical vector - its element set to FALSE sets
the prior mean for the autoregressive parameters of the Nth equation to the random walk process,
otherwise to white noise.
A new complete specification for the homoskedastic bsvar model BSVAR.
BSVAR$get_normal()Returns the logical value of whether the conditional shock distribution is normal.
BSVAR$get_normal()
spec = specify_bsvar$new(us_fiscal_lsuw) spec$get_normal()
BSVAR$get_data_matrices()Returns the data matrices as the DataMatricesBSVAR object.
BSVAR$get_data_matrices()
data(us_fiscal_lsuw) spec = specify_bsvar$new( data = us_fiscal_lsuw, p = 4 ) spec$get_data_matrices()
BSVAR$get_identification()Returns the identifying restrictions as the IdentificationBSVARs object.
BSVAR$get_identification()
data(us_fiscal_lsuw) spec = specify_bsvar$new( data = us_fiscal_lsuw, p = 4 ) spec$get_identification()
BSVAR$get_prior()Returns the prior specification as the PriorBSVAR object.
BSVAR$get_prior()
data(us_fiscal_lsuw) spec = specify_bsvar$new( data = us_fiscal_lsuw, p = 4 ) spec$get_prior()
BSVAR$get_starting_values()Returns the starting values as the StartingValuesBSVAR object.
BSVAR$get_starting_values()
data(us_fiscal_lsuw) spec = specify_bsvar$new( data = us_fiscal_lsuw, p = 4 ) spec$get_starting_values()
BSVAR$clone()The objects of this class are cloneable with this method.
BSVAR$clone(deep = FALSE)
deepWhether to make a deep clone.
estimate, specify_posterior_bsvar
data(us_fiscal_lsuw)
spec = specify_bsvar$new(
data = us_fiscal_lsuw,
p = 4
)
## ------------------------------------------------
## Method `BSVAR$get_normal()`
## ------------------------------------------------
spec = specify_bsvar$new(us_fiscal_lsuw)
spec$get_normal()
## ------------------------------------------------
## Method `BSVAR$get_data_matrices()`
## ------------------------------------------------
data(us_fiscal_lsuw)
spec = specify_bsvar$new(
data = us_fiscal_lsuw,
p = 4
)
spec$get_data_matrices()
## ------------------------------------------------
## Method `BSVAR$get_identification()`
## ------------------------------------------------
data(us_fiscal_lsuw)
spec = specify_bsvar$new(
data = us_fiscal_lsuw,
p = 4
)
spec$get_identification()
## ------------------------------------------------
## Method `BSVAR$get_prior()`
## ------------------------------------------------
data(us_fiscal_lsuw)
spec = specify_bsvar$new(
data = us_fiscal_lsuw,
p = 4
)
spec$get_prior()
## ------------------------------------------------
## Method `BSVAR$get_starting_values()`
## ------------------------------------------------
data(us_fiscal_lsuw)
spec = specify_bsvar$new(
data = us_fiscal_lsuw,
p = 4
)
spec$get_starting_values()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.