| specify_bsvar_exh | R Documentation |
The class BSVAREXH presents complete specification for the BSVAR model with exogenous heteroskedastic regime change.
pa non-negative integer specifying the autoregressive lag order of the model.
identificationan object IdentificationBSVARs with the identifying restrictions.
prioran object PriorBSVAREXH with the prior specification.
data_matricesan object DataMatricesBSVAR with the data matrices.
starting_valuesan object StartingValuesBSVAREXH with the starting values.
variance_regimesa T-vector with exogenous regime indicators that are integer
numbers associating the time observation with heteroskedastic regime.
BSVAREXH$new()Create a new specification of the BSVAR model with Markov Switching Heteroskedasticity, BSVAREXH.
BSVAREXH$new(
data,
p = 1L,
B,
A,
distribution = c("norm", "t"),
exogenous = NULL,
stationary = rep(FALSE, ncol(data)),
variance_regimes = NULL
)
dataa (T+p)xN matrix with time series data.
pa positive integer providing model's autoregressive lag order.
Ba logical NxN matrix containing value TRUE for the
elements of the structural matrix B to be estimated and value FALSE
for exclusion restrictions to be set to zero.
Aa logical NxK matrix containing value TRUE for the elements of
the autoregressive matrix A to be estimated and value FALSE for exclusion restrictions
to be set to zero.
distributiona character string specifying the conditional distribution
of structural shocks. Value "norm" sets it to the normal distribution,
while value "t" sets the Student-t distribution.
exogenousa (T+p)xd matrix of exogenous variables.
stationaryan N logical vector - its element set to FALSE sets
the prior mean for the autoregressive parameters of the Nth equation to the random walk process,
otherwise to white noise.
variance_regimesa T-vector with exogenous regime indicators that are integer
numbers associating the time observation with heteroskedastic regime.
A new complete specification for the bsvar model with exogenous heteroskedastic regime change, BSVAREXH.
BSVAREXH$get_normal()Returns the logical value of whether the conditional shock distribution is normal.
BSVAREXH$get_normal()
spec = specify_bsvar_exh$new(us_fiscal_lsuw) spec$get_normal()
BSVAREXH$get_data_matrices()Returns the data matrices as the DataMatricesBSVAR object.
BSVAREXH$get_data_matrices()
spec = specify_bsvar_exh$new(us_fiscal_lsuw) spec$get_data_matrices()
BSVAREXH$get_identification()Returns the identifying restrictions as the IdentificationBSVARs object.
BSVAREXH$get_identification()
spec = specify_bsvar_exh$new(us_fiscal_lsuw) spec$get_identification()
BSVAREXH$get_prior()Returns the prior specification as the PriorBSVAREXH object.
BSVAREXH$get_prior()
spec = specify_bsvar_exh$new(us_fiscal_lsuw) spec$get_prior()
BSVAREXH$get_starting_values()Returns the starting values as the StartingValuesBSVAREXH object.
BSVAREXH$get_starting_values()
spec = specify_bsvar_exh$new(us_fiscal_lsuw) spec$get_starting_values()
BSVAREXH$clone()The objects of this class are cloneable with this method.
BSVAREXH$clone(deep = FALSE)
deepWhether to make a deep clone.
estimate, specify_posterior_bsvar_exh
spec = specify_bsvar_exh$new(us_fiscal_lsuw)
## ------------------------------------------------
## Method `BSVAREXH$get_normal()`
## ------------------------------------------------
spec = specify_bsvar_exh$new(us_fiscal_lsuw)
spec$get_normal()
## ------------------------------------------------
## Method `BSVAREXH$get_data_matrices()`
## ------------------------------------------------
spec = specify_bsvar_exh$new(us_fiscal_lsuw)
spec$get_data_matrices()
## ------------------------------------------------
## Method `BSVAREXH$get_identification()`
## ------------------------------------------------
spec = specify_bsvar_exh$new(us_fiscal_lsuw)
spec$get_identification()
## ------------------------------------------------
## Method `BSVAREXH$get_prior()`
## ------------------------------------------------
spec = specify_bsvar_exh$new(us_fiscal_lsuw)
spec$get_prior()
## ------------------------------------------------
## Method `BSVAREXH$get_starting_values()`
## ------------------------------------------------
spec = specify_bsvar_exh$new(us_fiscal_lsuw)
spec$get_starting_values()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.