| specify_bsvar_mix | R Documentation |
The class BSVARMIX presents complete specification for the BSVAR model with a zero-mean mixture of normals model for structural shocks.
BSVARMSH -> BSVARMIX
pa non-negative integer specifying the autoregressive lag order of the model.
identificationan object IdentificationBSVARs with the identifying restrictions.
prioran object PriorBSVARMIX with the prior specification.
data_matricesan object DataMatricesBSVAR with the data matrices.
starting_valuesan object StartingValuesBSVARMIX with the starting values.
finiteMa logical value - if true a finite mixture model is estimated. Otherwise, a sparse mixture model is estimated in which M=20 and the number of visited states is estimated.
BSVARMSH$get_data_matrices()BSVARMSH$get_identification()BSVARMSH$get_normal()BSVARMSH$get_prior()BSVARMSH$get_starting_values()BSVARMIX$new()Create a new specification of the BSVAR model with a zero-mean mixture of normals model for structural shocks, BSVARMIX.
BSVARMIX$new(
data,
p = 1L,
M = 2L,
B,
A,
distribution = c("norm", "t"),
exogenous = NULL,
stationary = rep(FALSE, ncol(data)),
finiteM = TRUE
)
dataa (T+p)xN matrix with time series data.
pa positive integer providing model's autoregressive lag order.
Man integer greater than 1 - the number of components of the mixture of normals.
Ba logical NxN matrix containing value TRUE for the elements of the structural matrix B to be estimated and value FALSE for exclusion restrictions to be set to zero.
Aa logical NxK matrix containing value TRUE for the elements of
the autoregressive matrix A to be estimated and value FALSE for exclusion restrictions
to be set to zero.
distributiona character string specifying the conditional distribution
of structural shocks. Value "norm" sets it to the normal distribution,
while value "t" sets the Student-t distribution.
exogenousa (T+p)xd matrix of exogenous variables.
stationaryan N logical vector - its element set to FALSE sets
the prior mean for the autoregressive parameters of the Nth equation to the random walk process,
otherwise to white noise.
finiteMa logical value - if true a finite mixture model is estimated. Otherwise, a sparse mixture model is estimated in which M=20 and the number of visited states is estimated.
A new complete specification for the bsvar model with a zero-mean mixture of normals model for structural shocks, BSVARMIX.
BSVARMIX$clone()The objects of this class are cloneable with this method.
BSVARMIX$clone(deep = FALSE)
deepWhether to make a deep clone.
estimate, specify_posterior_bsvar_mix
data(us_fiscal_lsuw)
spec = specify_bsvar_mix$new(
data = us_fiscal_lsuw,
p = 4,
M = 2
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.