| specify_bsvar_sv | R Documentation |
The class BSVARSV presents complete specification for the BSVAR model with Stochastic Volatility heteroskedasticity.
pa non-negative integer specifying the autoregressive lag order of the model.
identificationan object IdentificationBSVARs with the identifying restrictions.
prioran object PriorBSVARSV with the prior specification.
data_matricesan object DataMatricesBSVAR with the data matrices.
starting_valuesan object StartingValuesBSVARSV with the starting values.
centred_sva logical value - if true a centred parameterisation of the Stochastic Volatility process is estimated. Otherwise, its non-centred parameterisation is estimated. See Lütkepohl, Shang, Uzeda, Woźniak (2022) for more info.
BSVARSV$new()Create a new specification of the BSVAR model with Stochastic Volatility heteroskedasticity, BSVARSV.
BSVARSV$new(
data,
p = 1L,
B,
A,
distribution = c("norm", "t"),
exogenous = NULL,
centred_sv = FALSE,
stationary = rep(FALSE, ncol(data))
)
dataa (T+p)xN matrix with time series data.
pa positive integer providing model's autoregressive lag order.
Ba logical NxN matrix containing value TRUE for the elements of the structural matrix B to be estimated and value FALSE for exclusion restrictions to be set to zero.
Aa logical NxK matrix containing value TRUE for the elements of
the autoregressive matrix A to be estimated and value FALSE for exclusion restrictions
to be set to zero.
distributiona character string specifying the conditional distribution
of structural shocks. Value "norm" sets it to the normal distribution,
while value "t" sets the Student-t distribution.
exogenousa (T+p)xd matrix of exogenous variables.
centred_sva logical value. If FALSE a non-centred Stochastic Volatility processes for conditional variances are estimated. Otherwise, a centred process is estimated.
stationaryan N logical vector - its element set to FALSE sets
the prior mean for the autoregressive parameters of the Nth equation to the random walk process,
otherwise to white noise.
A new complete specification for the bsvar model with Stochastic Volatility heteroskedasticity, BSVARSV.
BSVARSV$get_normal()Returns the logical value of whether the conditional shock distribution is normal.
BSVARSV$get_normal()
spec = specify_bsvar_sv$new(us_fiscal_lsuw) spec$get_normal()
BSVARSV$get_data_matrices()Returns the data matrices as the DataMatricesBSVAR object.
BSVARSV$get_data_matrices()
data(us_fiscal_lsuw) spec = specify_bsvar_sv$new( data = us_fiscal_lsuw, p = 4 ) spec$get_data_matrices()
BSVARSV$get_identification()Returns the identifying restrictions as the IdentificationBSVARs object.
BSVARSV$get_identification()
data(us_fiscal_lsuw) spec = specify_bsvar_sv$new( data = us_fiscal_lsuw, p = 4 ) spec$get_identification()
BSVARSV$get_prior()Returns the prior specification as the PriorBSVARSV object.
BSVARSV$get_prior()
data(us_fiscal_lsuw) spec = specify_bsvar_sv$new( data = us_fiscal_lsuw, p = 4 ) spec$get_prior()
BSVARSV$get_starting_values()Returns the starting values as the StartingValuesBSVARSV object.
BSVARSV$get_starting_values()
data(us_fiscal_lsuw) spec = specify_bsvar_sv$new( data = us_fiscal_lsuw, p = 4 ) spec$get_starting_values()
BSVARSV$clone()The objects of this class are cloneable with this method.
BSVARSV$clone(deep = FALSE)
deepWhether to make a deep clone.
estimate, specify_posterior_bsvar_sv
data(us_fiscal_lsuw)
spec = specify_bsvar_sv$new(
data = us_fiscal_lsuw,
p = 4
)
## ------------------------------------------------
## Method `BSVARSV$get_normal()`
## ------------------------------------------------
spec = specify_bsvar_sv$new(us_fiscal_lsuw)
spec$get_normal()
## ------------------------------------------------
## Method `BSVARSV$get_data_matrices()`
## ------------------------------------------------
data(us_fiscal_lsuw)
spec = specify_bsvar_sv$new(
data = us_fiscal_lsuw,
p = 4
)
spec$get_data_matrices()
## ------------------------------------------------
## Method `BSVARSV$get_identification()`
## ------------------------------------------------
data(us_fiscal_lsuw)
spec = specify_bsvar_sv$new(
data = us_fiscal_lsuw,
p = 4
)
spec$get_identification()
## ------------------------------------------------
## Method `BSVARSV$get_prior()`
## ------------------------------------------------
data(us_fiscal_lsuw)
spec = specify_bsvar_sv$new(
data = us_fiscal_lsuw,
p = 4
)
spec$get_prior()
## ------------------------------------------------
## Method `BSVARSV$get_starting_values()`
## ------------------------------------------------
data(us_fiscal_lsuw)
spec = specify_bsvar_sv$new(
data = us_fiscal_lsuw,
p = 4
)
spec$get_starting_values()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.