summary.PosteriorBSVAR: Provides posterior summary of homoskedastic Structural VAR...

View source: R/summary.R

summary.PosteriorBSVARR Documentation

Provides posterior summary of homoskedastic Structural VAR estimation

Description

Provides posterior mean, standard deviations, as well as 5 and 95 percentiles of the parameters: the structural matrix B, autoregressive parameters A, and hyper parameters.

Usage

## S3 method for class 'PosteriorBSVAR'
summary(object, ...)

Arguments

object

an object of class PosteriorBSVAR obtained using the estimate() function applied to homoskedastic Bayesian Structural VAR model specification set by function specify_bsvar$new() containing draws from the posterior distribution of the parameters.

...

additional arguments affecting the summary produced.

Value

A list reporting the posterior mean, standard deviations, as well as 5 and 95 percentiles of the parameters: the structural matrix B, autoregressive parameters A, and hyper-parameters.

Author(s)

Tomasz Woźniak wozniak.tom@pm.me

See Also

estimate, specify_bsvar

Examples

specification = specify_bsvar$new(us_fiscal_lsuw)
burn_in      = estimate(specification, 5)
posterior    = estimate(burn_in, 5)
summ         = summary(posterior)
summ

# workflow with the pipe |>
############################################################
us_fiscal_lsuw |>
  specify_bsvar$new() |>
  estimate(S = 5) |> 
  estimate(S = 5) |> 
  summary() -> summ
summ


bsvars documentation built on Aug. 22, 2026, 5:09 p.m.