| summary.PosteriorBSVAR | R Documentation |
Provides posterior mean, standard deviations, as well as 5 and 95
percentiles of the parameters: the structural matrix B, autoregressive
parameters A, and hyper parameters.
## S3 method for class 'PosteriorBSVAR'
summary(object, ...)
object |
an object of class PosteriorBSVAR obtained using the
|
... |
additional arguments affecting the summary produced. |
A list reporting the posterior mean, standard deviations, as well as 5 and 95
percentiles of the parameters: the structural matrix B, autoregressive
parameters A, and hyper-parameters.
Tomasz Woźniak wozniak.tom@pm.me
estimate, specify_bsvar
specification = specify_bsvar$new(us_fiscal_lsuw)
burn_in = estimate(specification, 5)
posterior = estimate(burn_in, 5)
summ = summary(posterior)
summ
# workflow with the pipe |>
############################################################
us_fiscal_lsuw |>
specify_bsvar$new() |>
estimate(S = 5) |>
estimate(S = 5) |>
summary() -> summ
summ
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.