summary.PosteriorBSVAREXH: Provides posterior summary of heteroskedastic Structural VAR...

View source: R/summary.R

summary.PosteriorBSVAREXHR Documentation

Provides posterior summary of heteroskedastic Structural VAR estimation

Description

Provides posterior mean, standard deviations, as well as 5 and 95 percentiles of the parameters: the structural matrix B, autoregressive parameters A, and hyper parameters.

Usage

## S3 method for class 'PosteriorBSVAREXH'
summary(object, ...)

Arguments

object

an object of class PosteriorBSVAREXH obtained using the estimate() function applied to heteroskedastic Bayesian Structural VAR model specification set by function specify_bsvar_exh$new() containing draws from the posterior distribution of the parameters.

...

additional arguments affecting the summary produced.

Value

A list reporting the posterior mean, standard deviations, as well as 5 and 95 percentiles of the parameters: the structural matrix B, autoregressive parameters A, and hyper-parameters.

Author(s)

Tomasz Woźniak wozniak.tom@pm.me

See Also

estimate, specify_bsvar_exh

Examples

spec  = specify_bsvar_exh$new(us_fiscal_lsuw)
burn  = estimate(spec, 5)
post  = estimate(burn, 5)
summ  = summary(post)
summ

# workflow with the pipe |>
############################################################
us_fiscal_lsuw |>
  specify_bsvar_exh$new() |>
  estimate(S = 5) |> 
  estimate(S = 5) |> 
  summary() -> summ
summ


bsvars documentation built on Aug. 22, 2026, 5:09 p.m.