summary.PosteriorBSVARMIX: Provides posterior summary of non-normal Structural VAR...

View source: R/summary.R

summary.PosteriorBSVARMIXR Documentation

Provides posterior summary of non-normal Structural VAR estimation

Description

Provides posterior mean, standard deviations, as well as 5 and 95 percentiles of the parameters: the structural matrix B, autoregressive parameters A, and hyper parameters.

Usage

## S3 method for class 'PosteriorBSVARMIX'
summary(object, ...)

Arguments

object

an object of class PosteriorBSVARMIX obtained using the estimate() function applied to non-normal Bayesian Structural VAR model specification set by function specify_bsvar_mix$new() containing draws from the posterior distribution of the parameters.

...

additional arguments affecting the summary produced.

Value

A list reporting the posterior mean, standard deviations, as well as 5 and 95 percentiles of the parameters: the structural matrix B, autoregressive parameters A, and hyper-parameters.

Author(s)

Tomasz Woźniak wozniak.tom@pm.me

See Also

estimate, specify_bsvar_mix

Examples

specification  = specify_bsvar_mix$new(us_fiscal_lsuw)
burn_in        = estimate(specification, 5)
posterior      = estimate(burn_in, 5)
summ           = summary(posterior)
summ$A$equation1[,1] # access posterior means

# workflow with the pipe |>
############################################################
set.seed(123)
us_fiscal_lsuw |>
  specify_bsvar_mix$new() |>
  estimate(S = 5) |> 
  estimate(S = 5) |> 
  summary() -> summ
summ$A$equation1[,1] # access posterior means


bsvars documentation built on Aug. 22, 2026, 5:09 p.m.