| summary.PosteriorBSVARMIX | R Documentation |
Provides posterior mean, standard deviations, as well as 5 and 95
percentiles of the parameters: the structural matrix B, autoregressive
parameters A, and hyper parameters.
## S3 method for class 'PosteriorBSVARMIX'
summary(object, ...)
object |
an object of class PosteriorBSVARMIX obtained using the
|
... |
additional arguments affecting the summary produced. |
A list reporting the posterior mean, standard deviations, as well as 5 and 95
percentiles of the parameters: the structural matrix B, autoregressive
parameters A, and hyper-parameters.
Tomasz Woźniak wozniak.tom@pm.me
estimate, specify_bsvar_mix
specification = specify_bsvar_mix$new(us_fiscal_lsuw)
burn_in = estimate(specification, 5)
posterior = estimate(burn_in, 5)
summ = summary(posterior)
summ$A$equation1[,1] # access posterior means
# workflow with the pipe |>
############################################################
set.seed(123)
us_fiscal_lsuw |>
specify_bsvar_mix$new() |>
estimate(S = 5) |>
estimate(S = 5) |>
summary() -> summ
summ$A$equation1[,1] # access posterior means
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.