summary.PosteriorBSVART: Provides posterior summary of Structural VAR with...

View source: R/summary.R

summary.PosteriorBSVARTR Documentation

Provides posterior summary of Structural VAR with t-distributed shocks estimation

Description

Provides posterior mean, standard deviations, as well as 5 and 95 percentiles of the parameters: the structural matrix B, autoregressive parameters A, hyper-parameters, and Student-t degrees-of-freedom parameter \nu.

Usage

## S3 method for class 'PosteriorBSVART'
summary(object, ...)

Arguments

object

an object of class PosteriorBSVART obtained using the estimate() function applied to homoskedastic Bayesian Structural VAR model specification set by function specify_bsvar$new() containing draws from the posterior distribution of the parameters.

...

additional arguments affecting the summary produced.

Value

A list reporting the posterior mean, standard deviations, as well as 5 and 95 percentiles of the parameters: the structural matrix B, autoregressive parameters A, hyper-parameters, and Student-t degrees-of-freedom parameter \nu.

Author(s)

Tomasz Woźniak wozniak.tom@pm.me

See Also

estimate, specify_bsvar_t

Examples

specification  = specify_bsvar_t$new(us_fiscal_lsuw)
burn_in        = estimate(specification, 5)
posterior      = estimate(burn_in, 5)
summ           = summary(posterior)
summ$A$equation1[,1] # access posterior means

# workflow with the pipe |>
############################################################
set.seed(123)
us_fiscal_lsuw |>
  specify_bsvar_t$new() |>
  estimate(S = 5) |> 
  estimate(S = 5) |> 
  summary() -> summ
summ$A$equation1[,1] # access posterior means


bsvars documentation built on Aug. 22, 2026, 5:09 p.m.