| summary.PosteriorFitted | R Documentation |
Provides posterior summary of the fitted values including their mean, standard deviations, as well as 5 and 95 percentiles.
## S3 method for class 'PosteriorFitted'
summary(object, ...)
object |
an object of class PosteriorFitted obtained using the
|
... |
additional arguments affecting the summary produced. |
A list reporting the posterior mean, standard deviations, as well as 5 and 95 percentiles of the fitted values for each of the shocks and periods.
Tomasz Woźniak wozniak.tom@pm.me
compute_fitted_values
specification = specify_bsvar$new(us_fiscal_lsuw)
burn_in = estimate(specification, 5)
posterior = estimate(burn_in, 5)
# compute fitted values
fitted = compute_fitted_values(posterior)
fitted_summary = summary(fitted)
fitted_summary$ttr[,1] # access posterior mean of ttr
# workflow with the pipe |>
############################################################
us_fiscal_lsuw |>
specify_bsvar$new() |>
estimate(S = 5) |>
estimate(S = 5) |>
compute_fitted_values() |>
summary() -> fitted_summary
fitted_summary$ttr[,1] # access posterior mean of ttr
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.