summary.PosteriorHD: Provides posterior summary of historical decompositions

View source: R/summary.R

summary.PosteriorHDR Documentation

Provides posterior summary of historical decompositions

Description

Provides posterior means of the historical decompositions variable by variable.

Usage

## S3 method for class 'PosteriorHD'
summary(object, ...)

Arguments

object

an object of class PosteriorHD obtained using the compute_historical_decompositions() function containing posterior draws of historical decompositions.

...

additional arguments affecting the summary produced.

Value

A list reporting the posterior means of historical decompositions for each of the variables.

Author(s)

Tomasz Woźniak wozniak.tom@pm.me

See Also

compute_historical_decompositions

Examples

specification  = specify_bsvar$new(diff(us_fiscal_lsuw))
burn_in        = estimate(specification, 5)
posterior      = estimate(burn_in, 5)

# compute historical decompositions
hds            = compute_historical_decompositions(posterior)
hds_summary    = summary(hds)
head(hds_summary$gdp) # browse the contributions

# workflow with the pipe |>
############################################################
diff(us_fiscal_lsuw) |>
  specify_bsvar$new() |>
  estimate(S = 5) |> 
  estimate(S = 5) |> 
  compute_historical_decompositions() |>
  summary() -> hds_summary
hds_summary$gdp # browse the contributions


bsvars documentation built on Aug. 22, 2026, 5:09 p.m.