| summary.PosteriorHD | R Documentation |
Provides posterior means of the historical decompositions variable by variable.
## S3 method for class 'PosteriorHD'
summary(object, ...)
object |
an object of class PosteriorHD obtained using the
|
... |
additional arguments affecting the summary produced. |
A list reporting the posterior means of historical decompositions for each of the variables.
Tomasz Woźniak wozniak.tom@pm.me
compute_historical_decompositions
specification = specify_bsvar$new(diff(us_fiscal_lsuw))
burn_in = estimate(specification, 5)
posterior = estimate(burn_in, 5)
# compute historical decompositions
hds = compute_historical_decompositions(posterior)
hds_summary = summary(hds)
head(hds_summary$gdp) # browse the contributions
# workflow with the pipe |>
############################################################
diff(us_fiscal_lsuw) |>
specify_bsvar$new() |>
estimate(S = 5) |>
estimate(S = 5) |>
compute_historical_decompositions() |>
summary() -> hds_summary
hds_summary$gdp # browse the contributions
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.