| summary.PosteriorRegimePr | R Documentation |
Provides posterior summary of regime probabilities including their mean, standard deviations, as well as 5 and 95 percentiles.
## S3 method for class 'PosteriorRegimePr'
summary(object, ...)
object |
an object of class PosteriorRegimePr obtained using the
|
... |
additional arguments affecting the summary produced. |
A list reporting the posterior mean and standard deviations of the regime probabilities.
Tomasz Woźniak wozniak.tom@pm.me
compute_regime_probabilities
specification = specify_bsvar_msh$new(us_fiscal_lsuw)
burn_in = estimate(specification, 5)
posterior = estimate(burn_in, 5)
# compute regime probabilities
rp = compute_regime_probabilities(posterior)
rp_summary = summary(rp)
head(rp_summary$MarkovProcess1$regime1) # browse the results
# workflow with the pipe |>
############################################################
us_fiscal_lsuw |>
specify_bsvar_msh$new() |>
estimate(S = 5) |>
estimate(S = 5) |>
compute_regime_probabilities() |>
summary() -> rp_summary
head(rp_summary$MarkovProcess1$regime1) # browse the results
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.