| summary.PosteriorShocks | R Documentation |
Provides posterior summary of the structural shocks including their mean, standard deviations, as well as 5 and 95 percentiles.
## S3 method for class 'PosteriorShocks'
summary(object, ...)
object |
an object of class PosteriorShocks obtained using the
|
... |
additional arguments affecting the summary produced. |
A list reporting the posterior mean, standard deviations, as well as 5 and 95 percentiles of the structural shocks for each of the equations and periods.
Tomasz Woźniak wozniak.tom@pm.me
compute_structural_shocks
specification = specify_bsvar$new(us_fiscal_lsuw)
burn_in = estimate(specification, 5)
posterior = estimate(burn_in, 5)
# compute structural shocks
shocks = compute_structural_shocks(posterior)
shocks_summary = summary(shocks)
head(shocks_summary$shock1)
# workflow with the pipe |>
############################################################
set.seed(123)
us_fiscal_lsuw |>
specify_bsvar$new() |>
estimate(S = 5) |>
estimate(S = 5) |>
compute_structural_shocks() |>
summary() -> shocks_summary
head(shocks_summary$shock1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.