| summary.PosteriorSigma | R Documentation |
Provides posterior summary of structural shocks' conditional standard deviations including their mean, standard deviations, as well as 5 and 95 percentiles.
## S3 method for class 'PosteriorSigma'
summary(object, ...)
object |
an object of class PosteriorSigma obtained using the
|
... |
additional arguments affecting the summary produced. |
A list reporting the posterior mean, standard deviations, as well as 5 and 95 percentiles of the structural shocks' conditional standard deviations for each of the shocks and periods.
Tomasz Woźniak wozniak.tom@pm.me
compute_conditional_sd
specification = specify_bsvar_sv$new(us_fiscal_lsuw)
burn_in = estimate(specification, 5)
posterior = estimate(burn_in, 5)
# compute structural shocks' conditional standard deviations
sigma = compute_conditional_sd(posterior)
sigma_summary = summary(sigma)
sigma_summary$shock1[,1] # access posterior mean of shock1
# workflow with the pipe |>
############################################################
set.seed(123)
us_fiscal_lsuw |>
specify_bsvar_sv$new() |>
estimate(S = 5) |>
estimate(S = 5) |>
compute_conditional_sd() |>
summary() -> sigma_summary
sigma_summary$shock1[,1]
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.